-- Fendt615LSA
-- Specialisation for the Fendt 611 LSA
--
-- by fruktor
-- www.eifok-team.de
-- 

Fendt615LSA = {};


function Fendt615LSA.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Steerable, specializations);
end;


function Fendt615LSA:load(xmlFile)	

	self.trailerAttacherRotateNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.trailerAttacherRotateNode#index") );

	--###
	self.moveDownIntervall = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.moveDownIntervall#ms"), 1000);
	self.updateJoint = false;
	self.doLowering = false;
	self.loweringDone = false;
	self.nextAction = false;
	self.delay = 0;
	self.implementCount = 0;		

	--###
	self.windowsOpened = false;
	
	--###
	for i,j in pairs(self.mc[1]) do
		local x,y,z = getTranslation(self.movingTools[j].node);
		self.movingTools[j].origPos = {x,y,z};		
	end;	
	
end;


function Fendt615LSA:postLoad(xmlFile)

end;


function Fendt615LSA:delete()
end;

function Fendt615LSA:readStream(streamId, connection)
end;

function Fendt615LSA:writeStream(streamId, connection)	
end;

function Fendt615LSA:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Fendt615LSA:keyEvent(unicode, sym, modifier, isDown)

end;

function Fendt615LSA:update(dt)
	
	--###
	if Vehicle.debugRendering then
	end;	
	
	if self:getIsActive() then
		if self.isClient and self:getIsActiveForInput(false) and not self:hasInputConflictWithSelection() then
			if InputBinding.hasEvent(InputBinding.LOWER_ALL_IMPLEMENTS) then
				if self.implementCount == 2 then			
					self.loweringDone = false;
					self.delay = self.moveDownIntervall;
					self.doLowering = true;
					self.nextAction = not self.attacherJoints[1].moveDown;
					if self.attacherJoints[2].moveDown ~= not self.nextAction then 
						self.nextAction = false;
					end;
				end;
			elseif InputBinding.hasEvent(InputBinding.RESET_MOVEABLE_SEAT_MC) then							-- 
				for i,j in pairs(self.mc[1]) do
					setTranslation(self.movingTools[j].node, unpack(self.movingTools[j].origPos));
					self.movingTools[j].curTrans = { unpack(self.movingTools[j].origPos) };
					Cylindered.setDirty(self, self.movingTools[j]);
				end;
			end;		
		end;
	end;
	

	if self.isClient then
	
		if self.checkTrailerAttacherRot == true then 
			if self.attacherJoints[1].jointIndex ~= 0 or 
				self.attacherJoints[4].jointIndex ~= 0 then
				--self.attacherJoints[3].jointIndex ~= 0 then
				setRotation(self.trailerAttacherRotateNode, 0, Utils.degToRad(-180), 0);
			else
				setRotation(self.trailerAttacherRotateNode, 0, 0, 0);
			end;	
			self.checkTrailerAttacherRot = false;
		end;	
		
	end;
	
end;

function Fendt615LSA:updateTick(dt)
	if self:getIsActive() then	
		if self.doLowering then	
			local back = self.attacherJoints[1];
			local front = self.attacherJoints[2];	
			if not self.loweringDone then
				self:setJointMoveDown(2, self.nextAction);
				self.loweringDone = true;
			end;			
			if self.loweringDone then
				self.delay = self.delay - dt;				
				if self.delay <= 0 then
					self:setJointMoveDown(1, self.nextAction);
					self.doLowering = false;
				end;
			end;
		end;
	end;

end;

function Fendt615LSA:draw()
	g_currentMission:addHelpButtonText(g_i18n:getText("RESET_MOVEABLE_SEAT_MC"), InputBinding.RESET_MOVEABLE_SEAT_MC);
	if self.implementCount == 2 then
		g_currentMission:addHelpButtonText(g_i18n:getText("LOWER_ALL_IMPLEMENTS"), InputBinding.LOWER_ALL_IMPLEMENTS);
	end;
end;

function Fendt615LSA:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)	
    return BaseMission.VEHICLE_LOAD_OK;
end;

function Fendt615LSA:getSaveAttributesAndNodes(nodeIdent)
end;

function Fendt615LSA:attachImplement(implement)	
	self.checkTrailerAttacherRot = true;
	local jointType = implement.object.attacherJoint.jointType;
	local jointIndex = implement.jointDescIndex;
	if jointType == Vehicle.JOINTTYPE_IMPLEMENT then
		if implement.object.needsLowering then
			self.implementCount = self.implementCount + 1;
		end;
	end;
end;

function Fendt615LSA:detachImplement(implementIndex)
	self.checkTrailerAttacherRot = true;
	local implement = self.attachedImplements[implementIndex];
	local jointIndex = implement.jointDescIndex;
	if implement.object.attacherJoint.jointType == Vehicle.JOINTTYPE_IMPLEMENT then
		if implement.object.needsLowering then
			self.implementCount = math.max(self.implementCount - 1, 0);
		end;	
	end;	
end;

